@@ -5,7 +5,7 @@
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 36 $"
+__version__ = "$Rev: 41 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -46,3 +46,7 @@ from dependencies import get_dependencies
 
 import multicore
 from multicore import *
+
+
+# use local import to not clash with setuptools itself.
+from .setuptools import get_datafiles
