@@ -1,5 +1,5 @@
 from easydev.paths import *
-
+import os
 
 
 def test_get_share_directory_path():
@@ -13,3 +13,7 @@ def test_get_share_directory_path():
 
 def test_get_share_directories():
     a = get_shared_directories("easydev", "themes")
+
+def test_get_share_file():
+    f = get_share_file("easydev", os.sep.join(["themes", "standard"]),
+"theme.conf")
